Changelog
=========


1.0.3 (2022-07-26)
------------------

- Fix missing plone.app.contentmenu zcml dependency for plone_displayviews menu
  [laulaz]

- Add gallery control panel to allow setting grid_image_scale and zoom_image_scale
  [MrTango]


1.0.2 (2021-09-29)
------------------

- fix python_requires definition in setup.py
  MrTango

- general cleanup and add an uninstall profile
  MrTango


1.0.1 (2020-07-07)
------------------

- Fix scale size in gallery grid view
  [MrTango]


1.0 (2020-07-07)
----------------

- Cleanup, fixed travis setup and isort version in tox setup
  [MrTango]


1.0a4 (2020-06-12)
------------------

- render img tag manually, to avoid having width and height attributes set
  [MrTango]


1.0a3 (2020-06-12)
------------------

- Fix flexbin image height
  [MrTango]

- Fix title and description in spotlight view
  [MrTango]


1.0a2 (2020-06-11)
------------------

- Fix resources files in released package
  [MrTango]

- Support also Collections not only Folders
  [MrTango]


1.0a1 (2020-06-11)
------------------

- Initial release.
  [MrTango]
